==> c2c.template-2.2.0-py3-none-any.whl: c2c/template/config.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2018, Camptocamp SA
# All rights reserved.

# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:

# 1. Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.

# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

# The views and conclusions contained in the software and documentation are those
# of the authors and should not be interpreted as representing official policies,
# either expressed or implied, of the FreeBSD Project.


import logging
import c2c.template
from typing import Dict, Any

LOG = logging.getLogger(__name__)


class _Config(object):
    """
    A central point where we can access to the application configuration.
    """

    _config = None  # type: Dict[str, Any]

    def init(self, configfile: str) -> None:
        self._config = c2c.template.get_config(configfile)

    def get(self, key: str) -> Any:
        if self._config is None:
            LOG.error("The init method should be called first")
            return None
        return self._config.get(key)

    def __getitem__(self, key: str) -> Any:
        if self._config is None:
            LOG.error("The init method should be called first")
            return None
        return self._config[key]

    def get_config(self) -> Dict[str, Any]:
        if self._config is None:
            LOG.error("The init method should be called first")
            return None
        return self._config


config = _Config()  # type: _Config

==> c2c.template-2.3.0-py3-none-any.whl: c2c/template/config.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2018, Camptocamp SA
# All rights reserved.

# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:

# 1. Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.

# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

# The views and conclusions contained in the software and documentation are those
# of the authors and should not be interpreted as representing official policies,
# either expressed or implied, of the FreeBSD Project.


import logging
from typing import Any, Dict

import c2c.template

LOG = logging.getLogger(__name__)


class _Config(object):
    """
    A central point where we can access to the application configuration.
    """

    _config = None  # type: Dict[str, Any]

    def init(self, configfile: str) -> None:
        self._config = c2c.template.get_config(configfile)

    def get(self, key: str) -> Any:
        if self._config is None:
            LOG.error("The init method should be called first")
            return None
        return self._config.get(key)

    def __getitem__(self, key: str) -> Any:
        if self._config is None:
            LOG.error("The init method should be called first")
            return None
        return self._config[key]

    def get_config(self) -> Dict[str, Any]:
        if self._config is None:
            LOG.error("The init method should be called first")
            return None
        return self._config


config = _Config()  # type: _Config
